all <- read.table("nanodrop.txt", sep="\t", h=T)
all$PROJECT <- factor(all$PROJECT, levels=c("Plantageae", "Picramniaceae", "Buxineae", "Aronia"))
all$AGE <- max(all$YEAR, na.rm=T) - all$YEAR

dir.create("res", showWarnings=F)

# ===
# GENERALITIES

table(all$PROJECT)
sum(table(all$PROJECT))
summary(all)

# ===
# COMPARING PURITY

tapply(all$PURITY, all$PROJECT, function(.x) median(.x, na.rm=T)) # Picramniaceae much lower
kruskal.test(PURITY ~ PROJECT, data=all) # significant
pairwise.wilcox.test(all$PURITY, all$PROJECT) # Picramniaceae significantly different (but not from Aronia)

# ===
# COMPARING RELATIVE CONCENTRATION (CONC/WEIGHT)

tapply(all$CONC/all$WEIGHT, all$PROJECT, function(.x) median(.x, na.rm=T)) # Plantageae and Picramniaceae are much less
kruskal.test(CONC/WEIGHT ~ PROJECT, data=all) # significant
# boxplot(log(CONC/WEIGHT) ~ PROJECT, data=all) # log transformation is better here
pairwise.wilcox.test(all$CONC/all$WEIGHT, all$PROJECT) # partially significant

# ===
# COMPARING AGE (for interaction)
tapply(all$AGE, all$PROJECT, function(.x) median(.x, na.rm=T)) # Picramniaceae much yourger
pdf("res/all_ages.pdf")
boxplot(AGE ~ PROJECT, data=all, ylab="Age of sample, years") # to show the statement above
dev.off()
kruskal.test(AGE ~ PROJECT, data=all) # significant
pairwise.wilcox.test(all$AGE, all$PROJECT) # Picramniaceae significantly different

# ===
# two PROTOCOLs
table(all$PROTOCOL, all$PROJECT) # only Plantageae is relevant
tapply(all[all$PROJECT=="Plantageae",]$PURITY, all[all$PROJECT=="Plantageae",]$PROTOCOL, function(.x) median(.x, na.rm=T))
wilcox.test(PURITY ~ PROTOCOL, data=all[all$PROJECT=="Plantageae",])
# PURITY ~ AGE for two PROTOCOLs
all.pap <- lm(PURITY ~ AGE * PROTOCOL, data=all[all$PROJECT=="Plantageae",]) # because only here both protocols were used extensively
summary(all.pap) # no difference

# ===
# PURITY ~ AGE for 4 groups
all.p4 <- lm(PURITY ~ AGE * PROJECT, data=all)
summary(all.p4) # different!

all1 <- all[!all$PURITY %in% boxplot.stats(all$PURITY)$out,]
pdf("res/all_purity_age.pdf")
plot(PURITY ~ AGE, data=all1)
abline(lm(PURITY ~ AGE, data=all1), lty=1, lwd=2)
abline(lm(PURITY ~ AGE, data=all1[all1$PROJECT=="Plantageae",]), lty=1)
abline(lm(PURITY ~ AGE, data=all1[all1$PROJECT=="Picramniaceae",]), lty=2)
abline(lm(PURITY ~ AGE, data=all1[all1$PROJECT=="Buxineae",]), lty=4)
abline(lm(PURITY ~ AGE, data=all1[all1$PROJECT=="Aronia",]), lty=5)
legend("bottomright", legend=c("All", levels(as.factor(all1$PROJECT))), lty=c(1,1:2,4:5), lwd=c(2,1,1,1,1))
dev.off()

AIC(all.p4)
all.p41 <- lm(PURITY ~ AGE + PROJECT, data=all) # no interactions
AIC(all.p41) # worse!

# ===
# log(CONC/WEIGHT) ~ AGE for 4 groups
all.c4 <- lm(log(CONC/WEIGHT) ~ AGE * PROJECT, data=all)
AIC(all.c4)
all.c41 <- lm(log(CONC/WEIGHT) ~ AGE + PROJECT, data=all) # no interactions
AIC(all.c41) # better!
summary(all.c41) # only Aronia and Buxineae are really different!

# ===
# Plantageae
pl <- all[all$PROJECT=="Plantageae",]
AGE <- pl$AGE

# ===
# CONC ~ AGE
# with(pl, scatter.smooth(AGE, CONC))
conc.age.lm <- lm(CONC ~ AGE, data=pl)
summary(conc.age.lm)

# plot(conc.age.lm)
new.frame <- data.frame(AGE=seq(min(AGE, na.rm=T), max(AGE, na.rm=T), along.with=AGE))
predicted.points <- predict(conc.age.lm, interval="confidence", newdata=new.frame)
pdf("res/pl_conc_age.pdf")
plot(CONC ~ AGE, data=pl, xlab="Age of Sample", ylab="Concentration of DNA", main="")
abline(conc.age.lm)
matlines(new.frame$AGE, predicted.points, col="black", lty=c(0,2,2))
dev.off()

# ===
# CONC ~ WEIGHT
# with(pl, scatter.smooth(WEIGHT, CONC))
conc.we <- lm(CONC ~ WEIGHT, data=pl)
summary(conc.we)

new.frame2 <- data.frame(WEIGHT=seq(min(pl$WEIGHT, na.rm=T), max(pl$WEIGHT, na.rm=T), along.with=pl$WEIGHT))
predicted.points2 <- predict(conc.we, interval="confidence", newdata=new.frame2)
pdf("res/pl_conc_weight.pdf")
plot(CONC ~ WEIGHT, data=pl, ylab="Concentration of DNA", xlab="Weight of Sample", main="")
abline(conc.we)
matlines(new.frame2$WEIGHT, predicted.points2, col="black", lty=c(0,2,2))
dev.off()
